import { Config as Config$1 } from 'typescript-eslint';

type ExtractConfig<T> = T extends Array<infer U> ? U : never;
type EslintConfig = ExtractConfig<Config$1>;
type EslintConfigRules = NonNullable<EslintConfig['rules']>;

type ConfigOptionsRestriction = {
    files: string | string[] | null;
    patterns?: Record<string, string | string[]>;
    paths?: Record<string, string>;
};
type ConfigOptions = {
    /**
     * Must be import.meta to resolve the files
     */
    meta?: {
        dirname?: string;
        url?: string;
    };
    /**
     * True if in a monorepo package and all dependencies are on the root package.json
     */
    monorepoPackageJson?: boolean;
    /**
     * Internal packages regex
     */
    internalPackagesRegex?: string;
    /**
     * Local packages (Comes after the internal packages)
     */
    localPackages?: string[];
    /**
     * Extra parser options to be merged
     */
    parserOptions?: Record<string, unknown>;
    /**
     * Packages that must be imported first
     */
    priorityPackages?: string[];
    /**
     * Files for dev
     */
    devFiles?: string[];
    /**
     * Files for common js rules
     */
    cjsFiles?: string[];
    /**
     * Restrict import rules
     */
    restrict?: ConfigOptionsRestriction[];
    /**
     * Global variables
     */
    globals?: Record<string, 'writable' | 'readonly' | 'off'>;
    /**
     * Ignores linting the files
     */
    ignores?: string[];
};
type Config = {
    /**
     * General rules for typescript (node)
     * @param options
     * @returns
     */
    ts: (options?: ConfigOptions) => EslintConfig[];
    /**
     * General rules for typescript for web
     * @param options
     * @returns
     */
    tsWeb: (options?: ConfigOptions) => EslintConfig[];
};
declare const config: Config;

export { type ConfigOptions, type ConfigOptionsRestriction, type EslintConfig, type EslintConfigRules, config as default };
